summaryrefslogtreecommitdiffstats
path: root/apps/user_ldap/lib
diff options
context:
space:
mode:
authorkondou <kondou@ts.unde.re>2014-03-21 20:23:31 +0100
committerkondou <kondou@ts.unde.re>2014-03-21 20:23:31 +0100
commitdda7129a243c7ebdbcdf9c2b5dbf167542402bc2 (patch)
treed03dff6783ebabb6273a19ed59a6b9b3731e923e /apps/user_ldap/lib
parent556c6eca2397eaa03c4503822d647c8b6cb5e70e (diff)
parent4be0b3f6cce540282c6745d6bf3d2a0fa4ac65b4 (diff)
downloadnextcloud-server-dda7129a243c7ebdbcdf9c2b5dbf167542402bc2.tar.gz
nextcloud-server-dda7129a243c7ebdbcdf9c2b5dbf167542402bc2.zip
Merge branch 'master' of https://github.com/owncloud/core into last_cron_log
Diffstat (limited to 'apps/user_ldap/lib')
-rw-r--r--apps/user_ldap/lib/access.php4
-rw-r--r--apps/user_ldap/lib/configuration.php4
-rw-r--r--apps/user_ldap/lib/connection.php2
3 files changed, 6 insertions, 4 deletions
diff --git a/apps/user_ldap/lib/configuration.php b/apps/user_ldap/lib/configuration.php
index 612a623e910..d42b1c05820 100644
--- a/apps/user_ldap/lib/configuration.php
+++ b/apps/user_ldap/lib/configuration.php
@@ -119,9 +119,9 @@ class Configuration {
$cta = $this->getConfigTranslationArray();
foreach($config as $inputkey => $val) {
- if(strpos($inputkey, '_') !== false && isset($cta[$inputkey])) {
+ if(strpos($inputkey, '_') !== false && array_key_exists($inputkey, $cta)) {
$key = $cta[$inputkey];
- } elseif(isset($this->config[$inputkey])) {
+ } elseif(array_key_exists($inputkey, $this->config)) {
$key = $inputkey;
} else {
continue;
diff --git a/apps/user_ldap/lib/connection.php b/apps/user_ldap/lib/connection.php
index b2075748a3b..08ac4ac626b 100644
--- a/apps/user_ldap/lib/connection.php
+++ b/apps/user_ldap/lib/connection.php
@@ -78,6 +78,8 @@ class Connection extends LDAPUtility {
//a cloned instance inherits the connection resource. It may use it,
//but it may not disconnect it
$this->dontDestruct = true;
+ $this->configuration = new Configuration($this->configPrefix,
+ !is_null($this->configID));
}
public function __get($name) {
diff --git a/apps/user_ldap/lib/access.php b/apps/user_ldap/lib/access.php
index b7e4023dd73..4d187bab8d5 100644
--- a/apps/user_ldap/lib/access.php
+++ b/apps/user_ldap/lib/access.php
@@ -1064,8 +1064,8 @@ class Access extends LDAPUtility {
return true;
}
- //for now, supported attributes are entryUUID, nsuniqueid, objectGUID
- $testAttributes = array('entryuuid', 'nsuniqueid', 'objectguid', 'guid');
+ //for now, supported attributes are entryUUID, nsuniqueid, objectGUID, ipaUniqueID
+ $testAttributes = array('entryuuid', 'nsuniqueid', 'objectguid', 'guid', 'ipauniqueid');
foreach($testAttributes as $attribute) {
$value = $this->readAttribute($dn, $attribute);